# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kv_rpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import bookkeeper.proto.kv_pb2 as kv__pb2
import bookkeeper.proto.storage_pb2 as storage__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kv_rpc.proto',
  package='bookkeeper.proto.kv.rpc',
  syntax='proto3',
  serialized_options=_b('\n)org.apache.bookkeeper.stream.proto.kv.rpcP\001'),
  serialized_pb=_b('\n\x0ckv_rpc.proto\x12\x17\x62ookkeeper.proto.kv.rpc\x1a\x08kv.proto\x1a\rstorage.proto\"C\n\rRoutingHeader\x12\x11\n\tstream_id\x18\x01 \x01(\x03\x12\x10\n\x08range_id\x18\x02 \x01(\x03\x12\r\n\x05r_key\x18\x03 \x01(\x0c\"\x84\x01\n\x0eResponseHeader\x12\x32\n\x04\x63ode\x18\x01 \x01(\x0e\x32$.bookkeeper.proto.storage.StatusCode\x12>\n\x0erouting_header\x18\x63 \x01(\x0b\x32&.bookkeeper.proto.kv.rpc.RoutingHeader\"\xb2\x04\n\x0cRangeRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x11\n\trange_end\x18\x02 \x01(\x0c\x12\r\n\x05limit\x18\x03 \x01(\x03\x12\x10\n\x08revision\x18\x04 \x01(\x03\x12\x43\n\nsort_order\x18\x05 \x01(\x0e\x32/.bookkeeper.proto.kv.rpc.RangeRequest.SortOrder\x12\x45\n\x0bsort_target\x18\x06 \x01(\x0e\x32\x30.bookkeeper.proto.kv.rpc.RangeRequest.SortTarget\x12\x14\n\x0cserializable\x18\x07 \x01(\x08\x12\x11\n\tkeys_only\x18\x08 \x01(\x08\x12\x12\n\ncount_only\x18\t \x01(\x08\x12\x18\n\x10min_mod_revision\x18\n \x01(\x03\x12\x18\n\x10max_mod_revision\x18\x0b \x01(\x03\x12\x1b\n\x13min_create_revision\x18\x0c \x01(\x03\x12\x1b\n\x13max_create_revision\x18\r \x01(\x03\x12\x36\n\x06header\x18\x63 \x01(\x0b\x32&.bookkeeper.proto.kv.rpc.RoutingHeader\".\n\tSortOrder\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x41SCEND\x10\x01\x12\x0b\n\x07\x44\x45SCEND\x10\x02\"B\n\nSortTarget\x12\x07\n\x03KEY\x10\x00\x12\x0b\n\x07VERSION\x10\x01\x12\n\n\x06\x43REATE\x10\x02\x12\x07\n\x03MOD\x10\x03\x12\t\n\x05VALUE\x10\x04\"\x91\x01\n\rRangeResponse\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.bookkeeper.proto.kv.rpc.ResponseHeader\x12*\n\x03kvs\x18\x02 \x03(\x0b\x32\x1d.bookkeeper.proto.kv.KeyValue\x12\x0c\n\x04more\x18\x03 \x01(\x08\x12\r\n\x05\x63ount\x18\x04 \x01(\x03\"\xc6\x01\n\nPutRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\r\n\x05lease\x18\x03 \x01(\x03\x12\x0f\n\x07prev_kv\x18\x04 \x01(\x08\x12\x14\n\x0cignore_value\x18\x05 \x01(\x08\x12\x14\n\x0cignore_lease\x18\x06 \x01(\x08\x12\x36\n\x06header\x18\x63 \x01(\x0b\x32&.bookkeeper.proto.kv.rpc.RoutingHeader\x12\x18\n\x10\x65xpected_version\x18\x64 \x01(\x03\"v\n\x0bPutResponse\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.bookkeeper.proto.kv.rpc.ResponseHeader\x12.\n\x07prev_kv\x18\x02 \x01(\x0b\x32\x1d.bookkeeper.proto.kv.KeyValue\"z\n\x10IncrementRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x03\x12\x11\n\tget_total\x18\x03 \x01(\x08\x12\x36\n\x06header\x18\x63 \x01(\x0b\x32&.bookkeeper.proto.kv.rpc.RoutingHeader\"b\n\x11IncrementResponse\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.bookkeeper.proto.kv.rpc.ResponseHeader\x12\x14\n\x0ctotal_amount\x18\x02 \x01(\x03\"}\n\x12\x44\x65leteRangeRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x11\n\trange_end\x18\x02 \x01(\x0c\x12\x0f\n\x07prev_kv\x18\x03 \x01(\x08\x12\x36\n\x06header\x18\x63 \x01(\x0b\x32&.bookkeeper.proto.kv.rpc.RoutingHeader\"\x90\x01\n\x13\x44\x65leteRangeResponse\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.bookkeeper.proto.kv.rpc.ResponseHeader\x12\x0f\n\x07\x64\x65leted\x18\x02 \x01(\x03\x12/\n\x08prev_kvs\x18\x03 \x03(\x0b\x32\x1d.bookkeeper.proto.kv.KeyValue\"\xdf\x01\n\tRequestOp\x12>\n\rrequest_range\x18\x01 \x01(\x0b\x32%.bookkeeper.proto.kv.rpc.RangeRequestH\x00\x12:\n\x0brequest_put\x18\x02 \x01(\x0b\x32#.bookkeeper.proto.kv.rpc.PutRequestH\x00\x12K\n\x14request_delete_range\x18\x03 \x01(\x0b\x32+.bookkeeper.proto.kv.rpc.DeleteRangeRequestH\x00\x42\t\n\x07request\"\xe7\x01\n\nResponseOp\x12@\n\x0eresponse_range\x18\x01 \x01(\x0b\x32&.bookkeeper.proto.kv.rpc.RangeResponseH\x00\x12<\n\x0cresponse_put\x18\x02 \x01(\x0b\x32$.bookkeeper.proto.kv.rpc.PutResponseH\x00\x12M\n\x15response_delete_range\x18\x03 \x01(\x0b\x32,.bookkeeper.proto.kv.rpc.DeleteRangeResponseH\x00\x42\n\n\x08response\"\xfd\x02\n\x07\x43ompare\x12>\n\x06result\x18\x01 \x01(\x0e\x32..bookkeeper.proto.kv.rpc.Compare.CompareResult\x12>\n\x06target\x18\x02 \x01(\x0e\x32..bookkeeper.proto.kv.rpc.Compare.CompareTarget\x12\x0b\n\x03key\x18\x03 \x01(\x0c\x12\x11\n\x07version\x18\x04 \x01(\x03H\x00\x12\x19\n\x0f\x63reate_revision\x18\x05 \x01(\x03H\x00\x12\x16\n\x0cmod_revision\x18\x06 \x01(\x03H\x00\x12\x0f\n\x05value\x18\x07 \x01(\x0cH\x00\"@\n\rCompareResult\x12\t\n\x05\x45QUAL\x10\x00\x12\x0b\n\x07GREATER\x10\x01\x12\x08\n\x04LESS\x10\x02\x12\r\n\tNOT_EQUAL\x10\x03\"<\n\rCompareTarget\x12\x0b\n\x07VERSION\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x07\n\x03MOD\x10\x02\x12\t\n\x05VALUE\x10\x03\x42\x0e\n\x0ctarget_union\"\xe1\x01\n\nTxnRequest\x12\x31\n\x07\x63ompare\x18\x01 \x03(\x0b\x32 .bookkeeper.proto.kv.rpc.Compare\x12\x33\n\x07success\x18\x02 \x03(\x0b\x32\".bookkeeper.proto.kv.rpc.RequestOp\x12\x33\n\x07\x66\x61ilure\x18\x03 \x03(\x0b\x32\".bookkeeper.proto.kv.rpc.RequestOp\x12\x36\n\x06header\x18\x63 \x01(\x0b\x32&.bookkeeper.proto.kv.rpc.RoutingHeader\"\x91\x01\n\x0bTxnResponse\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.bookkeeper.proto.kv.rpc.ResponseHeader\x12\x11\n\tsucceeded\x18\x02 \x01(\x08\x12\x36\n\tresponses\x18\x03 \x03(\x0b\x32#.bookkeeper.proto.kv.rpc.ResponseOp2\xdd\x03\n\x0cTableService\x12X\n\x05Range\x12%.bookkeeper.proto.kv.rpc.RangeRequest\x1a&.bookkeeper.proto.kv.rpc.RangeResponse\"\x00\x12R\n\x03Put\x12#.bookkeeper.proto.kv.rpc.PutRequest\x1a$.bookkeeper.proto.kv.rpc.PutResponse\"\x00\x12\x65\n\x06\x44\x65lete\x12+.bookkeeper.proto.kv.rpc.DeleteRangeRequest\x1a,.bookkeeper.proto.kv.rpc.DeleteRangeResponse\"\x00\x12R\n\x03Txn\x12#.bookkeeper.proto.kv.rpc.TxnRequest\x1a$.bookkeeper.proto.kv.rpc.TxnResponse\"\x00\x12\x64\n\tIncrement\x12).bookkeeper.proto.kv.rpc.IncrementRequest\x1a*.bookkeeper.proto.kv.rpc.IncrementResponse\"\x00\x42-\n)org.apache.bookkeeper.stream.proto.kv.rpcP\x01\x62\x06proto3')
  ,
  dependencies=[kv__pb2.DESCRIPTOR,storage__pb2.DESCRIPTOR,])



_RANGEREQUEST_SORTORDER = _descriptor.EnumDescriptor(
  name='SortOrder',
  full_name='bookkeeper.proto.kv.rpc.RangeRequest.SortOrder',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASCEND', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESCEND', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=719,
  serialized_end=765,
)
_sym_db.RegisterEnumDescriptor(_RANGEREQUEST_SORTORDER)

_RANGEREQUEST_SORTTARGET = _descriptor.EnumDescriptor(
  name='SortTarget',
  full_name='bookkeeper.proto.kv.rpc.RangeRequest.SortTarget',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KEY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERSION', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOD', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=767,
  serialized_end=833,
)
_sym_db.RegisterEnumDescriptor(_RANGEREQUEST_SORTTARGET)

_COMPARE_COMPARERESULT = _descriptor.EnumDescriptor(
  name='CompareResult',
  full_name='bookkeeper.proto.kv.rpc.Compare.CompareResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LESS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2502,
  serialized_end=2566,
)
_sym_db.RegisterEnumDescriptor(_COMPARE_COMPARERESULT)

_COMPARE_COMPARETARGET = _descriptor.EnumDescriptor(
  name='CompareTarget',
  full_name='bookkeeper.proto.kv.rpc.Compare.CompareTarget',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERSION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOD', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2568,
  serialized_end=2628,
)
_sym_db.RegisterEnumDescriptor(_COMPARE_COMPARETARGET)


_ROUTINGHEADER = _descriptor.Descriptor(
  name='RoutingHeader',
  full_name='bookkeeper.proto.kv.rpc.RoutingHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='bookkeeper.proto.kv.rpc.RoutingHeader.stream_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_id', full_name='bookkeeper.proto.kv.rpc.RoutingHeader.range_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r_key', full_name='bookkeeper.proto.kv.rpc.RoutingHeader.r_key', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=133,
)


_RESPONSEHEADER = _descriptor.Descriptor(
  name='ResponseHeader',
  full_name='bookkeeper.proto.kv.rpc.ResponseHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='bookkeeper.proto.kv.rpc.ResponseHeader.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='routing_header', full_name='bookkeeper.proto.kv.rpc.ResponseHeader.routing_header', index=1,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=268,
)


_RANGEREQUEST = _descriptor.Descriptor(
  name='RangeRequest',
  full_name='bookkeeper.proto.kv.rpc.RangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bookkeeper.proto.kv.rpc.RangeRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_end', full_name='bookkeeper.proto.kv.rpc.RangeRequest.range_end', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='bookkeeper.proto.kv.rpc.RangeRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='bookkeeper.proto.kv.rpc.RangeRequest.revision', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_order', full_name='bookkeeper.proto.kv.rpc.RangeRequest.sort_order', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_target', full_name='bookkeeper.proto.kv.rpc.RangeRequest.sort_target', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serializable', full_name='bookkeeper.proto.kv.rpc.RangeRequest.serializable', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keys_only', full_name='bookkeeper.proto.kv.rpc.RangeRequest.keys_only', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count_only', full_name='bookkeeper.proto.kv.rpc.RangeRequest.count_only', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_mod_revision', full_name='bookkeeper.proto.kv.rpc.RangeRequest.min_mod_revision', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_mod_revision', full_name='bookkeeper.proto.kv.rpc.RangeRequest.max_mod_revision', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_create_revision', full_name='bookkeeper.proto.kv.rpc.RangeRequest.min_create_revision', index=11,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_create_revision', full_name='bookkeeper.proto.kv.rpc.RangeRequest.max_create_revision', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='bookkeeper.proto.kv.rpc.RangeRequest.header', index=13,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RANGEREQUEST_SORTORDER,
    _RANGEREQUEST_SORTTARGET,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=833,
)


_RANGERESPONSE = _descriptor.Descriptor(
  name='RangeResponse',
  full_name='bookkeeper.proto.kv.rpc.RangeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='bookkeeper.proto.kv.rpc.RangeResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kvs', full_name='bookkeeper.proto.kv.rpc.RangeResponse.kvs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='more', full_name='bookkeeper.proto.kv.rpc.RangeResponse.more', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='bookkeeper.proto.kv.rpc.RangeResponse.count', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=981,
)


_PUTREQUEST = _descriptor.Descriptor(
  name='PutRequest',
  full_name='bookkeeper.proto.kv.rpc.PutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bookkeeper.proto.kv.rpc.PutRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='bookkeeper.proto.kv.rpc.PutRequest.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lease', full_name='bookkeeper.proto.kv.rpc.PutRequest.lease', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_kv', full_name='bookkeeper.proto.kv.rpc.PutRequest.prev_kv', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignore_value', full_name='bookkeeper.proto.kv.rpc.PutRequest.ignore_value', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignore_lease', full_name='bookkeeper.proto.kv.rpc.PutRequest.ignore_lease', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='bookkeeper.proto.kv.rpc.PutRequest.header', index=6,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expected_version', full_name='bookkeeper.proto.kv.rpc.PutRequest.expected_version', index=7,
      number=100, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=984,
  serialized_end=1182,
)


_PUTRESPONSE = _descriptor.Descriptor(
  name='PutResponse',
  full_name='bookkeeper.proto.kv.rpc.PutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='bookkeeper.proto.kv.rpc.PutResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_kv', full_name='bookkeeper.proto.kv.rpc.PutResponse.prev_kv', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1184,
  serialized_end=1302,
)


_INCREMENTREQUEST = _descriptor.Descriptor(
  name='IncrementRequest',
  full_name='bookkeeper.proto.kv.rpc.IncrementRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bookkeeper.proto.kv.rpc.IncrementRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='bookkeeper.proto.kv.rpc.IncrementRequest.amount', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_total', full_name='bookkeeper.proto.kv.rpc.IncrementRequest.get_total', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='bookkeeper.proto.kv.rpc.IncrementRequest.header', index=3,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1304,
  serialized_end=1426,
)


_INCREMENTRESPONSE = _descriptor.Descriptor(
  name='IncrementResponse',
  full_name='bookkeeper.proto.kv.rpc.IncrementResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='bookkeeper.proto.kv.rpc.IncrementResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_amount', full_name='bookkeeper.proto.kv.rpc.IncrementResponse.total_amount', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1428,
  serialized_end=1526,
)


_DELETERANGEREQUEST = _descriptor.Descriptor(
  name='DeleteRangeRequest',
  full_name='bookkeeper.proto.kv.rpc.DeleteRangeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bookkeeper.proto.kv.rpc.DeleteRangeRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_end', full_name='bookkeeper.proto.kv.rpc.DeleteRangeRequest.range_end', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_kv', full_name='bookkeeper.proto.kv.rpc.DeleteRangeRequest.prev_kv', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='bookkeeper.proto.kv.rpc.DeleteRangeRequest.header', index=3,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1528,
  serialized_end=1653,
)


_DELETERANGERESPONSE = _descriptor.Descriptor(
  name='DeleteRangeResponse',
  full_name='bookkeeper.proto.kv.rpc.DeleteRangeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='bookkeeper.proto.kv.rpc.DeleteRangeResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='bookkeeper.proto.kv.rpc.DeleteRangeResponse.deleted', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prev_kvs', full_name='bookkeeper.proto.kv.rpc.DeleteRangeResponse.prev_kvs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1656,
  serialized_end=1800,
)


_REQUESTOP = _descriptor.Descriptor(
  name='RequestOp',
  full_name='bookkeeper.proto.kv.rpc.RequestOp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_range', full_name='bookkeeper.proto.kv.rpc.RequestOp.request_range', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_put', full_name='bookkeeper.proto.kv.rpc.RequestOp.request_put', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_delete_range', full_name='bookkeeper.proto.kv.rpc.RequestOp.request_delete_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='bookkeeper.proto.kv.rpc.RequestOp.request',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1803,
  serialized_end=2026,
)


_RESPONSEOP = _descriptor.Descriptor(
  name='ResponseOp',
  full_name='bookkeeper.proto.kv.rpc.ResponseOp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_range', full_name='bookkeeper.proto.kv.rpc.ResponseOp.response_range', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_put', full_name='bookkeeper.proto.kv.rpc.ResponseOp.response_put', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_delete_range', full_name='bookkeeper.proto.kv.rpc.ResponseOp.response_delete_range', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='bookkeeper.proto.kv.rpc.ResponseOp.response',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2029,
  serialized_end=2260,
)


_COMPARE = _descriptor.Descriptor(
  name='Compare',
  full_name='bookkeeper.proto.kv.rpc.Compare',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='bookkeeper.proto.kv.rpc.Compare.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='bookkeeper.proto.kv.rpc.Compare.target', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='bookkeeper.proto.kv.rpc.Compare.key', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='bookkeeper.proto.kv.rpc.Compare.version', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_revision', full_name='bookkeeper.proto.kv.rpc.Compare.create_revision', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mod_revision', full_name='bookkeeper.proto.kv.rpc.Compare.mod_revision', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='bookkeeper.proto.kv.rpc.Compare.value', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPARE_COMPARERESULT,
    _COMPARE_COMPARETARGET,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target_union', full_name='bookkeeper.proto.kv.rpc.Compare.target_union',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2263,
  serialized_end=2644,
)


_TXNREQUEST = _descriptor.Descriptor(
  name='TxnRequest',
  full_name='bookkeeper.proto.kv.rpc.TxnRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='compare', full_name='bookkeeper.proto.kv.rpc.TxnRequest.compare', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='bookkeeper.proto.kv.rpc.TxnRequest.success', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure', full_name='bookkeeper.proto.kv.rpc.TxnRequest.failure', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='bookkeeper.proto.kv.rpc.TxnRequest.header', index=3,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2647,
  serialized_end=2872,
)


_TXNRESPONSE = _descriptor.Descriptor(
  name='TxnResponse',
  full_name='bookkeeper.proto.kv.rpc.TxnResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='bookkeeper.proto.kv.rpc.TxnResponse.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='succeeded', full_name='bookkeeper.proto.kv.rpc.TxnResponse.succeeded', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='responses', full_name='bookkeeper.proto.kv.rpc.TxnResponse.responses', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2875,
  serialized_end=3020,
)

_RESPONSEHEADER.fields_by_name['code'].enum_type = storage__pb2._STATUSCODE
_RESPONSEHEADER.fields_by_name['routing_header'].message_type = _ROUTINGHEADER
_RANGEREQUEST.fields_by_name['sort_order'].enum_type = _RANGEREQUEST_SORTORDER
_RANGEREQUEST.fields_by_name['sort_target'].enum_type = _RANGEREQUEST_SORTTARGET
_RANGEREQUEST.fields_by_name['header'].message_type = _ROUTINGHEADER
_RANGEREQUEST_SORTORDER.containing_type = _RANGEREQUEST
_RANGEREQUEST_SORTTARGET.containing_type = _RANGEREQUEST
_RANGERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_RANGERESPONSE.fields_by_name['kvs'].message_type = kv__pb2._KEYVALUE
_PUTREQUEST.fields_by_name['header'].message_type = _ROUTINGHEADER
_PUTRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_PUTRESPONSE.fields_by_name['prev_kv'].message_type = kv__pb2._KEYVALUE
_INCREMENTREQUEST.fields_by_name['header'].message_type = _ROUTINGHEADER
_INCREMENTRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_DELETERANGEREQUEST.fields_by_name['header'].message_type = _ROUTINGHEADER
_DELETERANGERESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_DELETERANGERESPONSE.fields_by_name['prev_kvs'].message_type = kv__pb2._KEYVALUE
_REQUESTOP.fields_by_name['request_range'].message_type = _RANGEREQUEST
_REQUESTOP.fields_by_name['request_put'].message_type = _PUTREQUEST
_REQUESTOP.fields_by_name['request_delete_range'].message_type = _DELETERANGEREQUEST
_REQUESTOP.oneofs_by_name['request'].fields.append(
  _REQUESTOP.fields_by_name['request_range'])
_REQUESTOP.fields_by_name['request_range'].containing_oneof = _REQUESTOP.oneofs_by_name['request']
_REQUESTOP.oneofs_by_name['request'].fields.append(
  _REQUESTOP.fields_by_name['request_put'])
_REQUESTOP.fields_by_name['request_put'].containing_oneof = _REQUESTOP.oneofs_by_name['request']
_REQUESTOP.oneofs_by_name['request'].fields.append(
  _REQUESTOP.fields_by_name['request_delete_range'])
_REQUESTOP.fields_by_name['request_delete_range'].containing_oneof = _REQUESTOP.oneofs_by_name['request']
_RESPONSEOP.fields_by_name['response_range'].message_type = _RANGERESPONSE
_RESPONSEOP.fields_by_name['response_put'].message_type = _PUTRESPONSE
_RESPONSEOP.fields_by_name['response_delete_range'].message_type = _DELETERANGERESPONSE
_RESPONSEOP.oneofs_by_name['response'].fields.append(
  _RESPONSEOP.fields_by_name['response_range'])
_RESPONSEOP.fields_by_name['response_range'].containing_oneof = _RESPONSEOP.oneofs_by_name['response']
_RESPONSEOP.oneofs_by_name['response'].fields.append(
  _RESPONSEOP.fields_by_name['response_put'])
_RESPONSEOP.fields_by_name['response_put'].containing_oneof = _RESPONSEOP.oneofs_by_name['response']
_RESPONSEOP.oneofs_by_name['response'].fields.append(
  _RESPONSEOP.fields_by_name['response_delete_range'])
_RESPONSEOP.fields_by_name['response_delete_range'].containing_oneof = _RESPONSEOP.oneofs_by_name['response']
_COMPARE.fields_by_name['result'].enum_type = _COMPARE_COMPARERESULT
_COMPARE.fields_by_name['target'].enum_type = _COMPARE_COMPARETARGET
_COMPARE_COMPARERESULT.containing_type = _COMPARE
_COMPARE_COMPARETARGET.containing_type = _COMPARE
_COMPARE.oneofs_by_name['target_union'].fields.append(
  _COMPARE.fields_by_name['version'])
_COMPARE.fields_by_name['version'].containing_oneof = _COMPARE.oneofs_by_name['target_union']
_COMPARE.oneofs_by_name['target_union'].fields.append(
  _COMPARE.fields_by_name['create_revision'])
_COMPARE.fields_by_name['create_revision'].containing_oneof = _COMPARE.oneofs_by_name['target_union']
_COMPARE.oneofs_by_name['target_union'].fields.append(
  _COMPARE.fields_by_name['mod_revision'])
_COMPARE.fields_by_name['mod_revision'].containing_oneof = _COMPARE.oneofs_by_name['target_union']
_COMPARE.oneofs_by_name['target_union'].fields.append(
  _COMPARE.fields_by_name['value'])
_COMPARE.fields_by_name['value'].containing_oneof = _COMPARE.oneofs_by_name['target_union']
_TXNREQUEST.fields_by_name['compare'].message_type = _COMPARE
_TXNREQUEST.fields_by_name['success'].message_type = _REQUESTOP
_TXNREQUEST.fields_by_name['failure'].message_type = _REQUESTOP
_TXNREQUEST.fields_by_name['header'].message_type = _ROUTINGHEADER
_TXNRESPONSE.fields_by_name['header'].message_type = _RESPONSEHEADER
_TXNRESPONSE.fields_by_name['responses'].message_type = _RESPONSEOP
DESCRIPTOR.message_types_by_name['RoutingHeader'] = _ROUTINGHEADER
DESCRIPTOR.message_types_by_name['ResponseHeader'] = _RESPONSEHEADER
DESCRIPTOR.message_types_by_name['RangeRequest'] = _RANGEREQUEST
DESCRIPTOR.message_types_by_name['RangeResponse'] = _RANGERESPONSE
DESCRIPTOR.message_types_by_name['PutRequest'] = _PUTREQUEST
DESCRIPTOR.message_types_by_name['PutResponse'] = _PUTRESPONSE
DESCRIPTOR.message_types_by_name['IncrementRequest'] = _INCREMENTREQUEST
DESCRIPTOR.message_types_by_name['IncrementResponse'] = _INCREMENTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRangeRequest'] = _DELETERANGEREQUEST
DESCRIPTOR.message_types_by_name['DeleteRangeResponse'] = _DELETERANGERESPONSE
DESCRIPTOR.message_types_by_name['RequestOp'] = _REQUESTOP
DESCRIPTOR.message_types_by_name['ResponseOp'] = _RESPONSEOP
DESCRIPTOR.message_types_by_name['Compare'] = _COMPARE
DESCRIPTOR.message_types_by_name['TxnRequest'] = _TXNREQUEST
DESCRIPTOR.message_types_by_name['TxnResponse'] = _TXNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RoutingHeader = _reflection.GeneratedProtocolMessageType('RoutingHeader', (_message.Message,), dict(
  DESCRIPTOR = _ROUTINGHEADER,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.RoutingHeader)
  ))
_sym_db.RegisterMessage(RoutingHeader)

ResponseHeader = _reflection.GeneratedProtocolMessageType('ResponseHeader', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEHEADER,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.ResponseHeader)
  ))
_sym_db.RegisterMessage(ResponseHeader)

RangeRequest = _reflection.GeneratedProtocolMessageType('RangeRequest', (_message.Message,), dict(
  DESCRIPTOR = _RANGEREQUEST,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.RangeRequest)
  ))
_sym_db.RegisterMessage(RangeRequest)

RangeResponse = _reflection.GeneratedProtocolMessageType('RangeResponse', (_message.Message,), dict(
  DESCRIPTOR = _RANGERESPONSE,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.RangeResponse)
  ))
_sym_db.RegisterMessage(RangeResponse)

PutRequest = _reflection.GeneratedProtocolMessageType('PutRequest', (_message.Message,), dict(
  DESCRIPTOR = _PUTREQUEST,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.PutRequest)
  ))
_sym_db.RegisterMessage(PutRequest)

PutResponse = _reflection.GeneratedProtocolMessageType('PutResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUTRESPONSE,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.PutResponse)
  ))
_sym_db.RegisterMessage(PutResponse)

IncrementRequest = _reflection.GeneratedProtocolMessageType('IncrementRequest', (_message.Message,), dict(
  DESCRIPTOR = _INCREMENTREQUEST,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.IncrementRequest)
  ))
_sym_db.RegisterMessage(IncrementRequest)

IncrementResponse = _reflection.GeneratedProtocolMessageType('IncrementResponse', (_message.Message,), dict(
  DESCRIPTOR = _INCREMENTRESPONSE,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.IncrementResponse)
  ))
_sym_db.RegisterMessage(IncrementResponse)

DeleteRangeRequest = _reflection.GeneratedProtocolMessageType('DeleteRangeRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETERANGEREQUEST,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.DeleteRangeRequest)
  ))
_sym_db.RegisterMessage(DeleteRangeRequest)

DeleteRangeResponse = _reflection.GeneratedProtocolMessageType('DeleteRangeResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERANGERESPONSE,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.DeleteRangeResponse)
  ))
_sym_db.RegisterMessage(DeleteRangeResponse)

RequestOp = _reflection.GeneratedProtocolMessageType('RequestOp', (_message.Message,), dict(
  DESCRIPTOR = _REQUESTOP,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.RequestOp)
  ))
_sym_db.RegisterMessage(RequestOp)

ResponseOp = _reflection.GeneratedProtocolMessageType('ResponseOp', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEOP,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.ResponseOp)
  ))
_sym_db.RegisterMessage(ResponseOp)

Compare = _reflection.GeneratedProtocolMessageType('Compare', (_message.Message,), dict(
  DESCRIPTOR = _COMPARE,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.Compare)
  ))
_sym_db.RegisterMessage(Compare)

TxnRequest = _reflection.GeneratedProtocolMessageType('TxnRequest', (_message.Message,), dict(
  DESCRIPTOR = _TXNREQUEST,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.TxnRequest)
  ))
_sym_db.RegisterMessage(TxnRequest)

TxnResponse = _reflection.GeneratedProtocolMessageType('TxnResponse', (_message.Message,), dict(
  DESCRIPTOR = _TXNRESPONSE,
  __module__ = 'kv_rpc_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.rpc.TxnResponse)
  ))
_sym_db.RegisterMessage(TxnResponse)


DESCRIPTOR._options = None

_TABLESERVICE = _descriptor.ServiceDescriptor(
  name='TableService',
  full_name='bookkeeper.proto.kv.rpc.TableService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3023,
  serialized_end=3500,
  methods=[
  _descriptor.MethodDescriptor(
    name='Range',
    full_name='bookkeeper.proto.kv.rpc.TableService.Range',
    index=0,
    containing_service=None,
    input_type=_RANGEREQUEST,
    output_type=_RANGERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Put',
    full_name='bookkeeper.proto.kv.rpc.TableService.Put',
    index=1,
    containing_service=None,
    input_type=_PUTREQUEST,
    output_type=_PUTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='bookkeeper.proto.kv.rpc.TableService.Delete',
    index=2,
    containing_service=None,
    input_type=_DELETERANGEREQUEST,
    output_type=_DELETERANGERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Txn',
    full_name='bookkeeper.proto.kv.rpc.TableService.Txn',
    index=3,
    containing_service=None,
    input_type=_TXNREQUEST,
    output_type=_TXNRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Increment',
    full_name='bookkeeper.proto.kv.rpc.TableService.Increment',
    index=4,
    containing_service=None,
    input_type=_INCREMENTREQUEST,
    output_type=_INCREMENTRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TABLESERVICE)

DESCRIPTOR.services_by_name['TableService'] = _TABLESERVICE

# @@protoc_insertion_point(module_scope)
