# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cluster.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import bookkeeper.proto.common_pb2 as common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cluster.proto',
  package='bookkeeper.proto.cluster',
  syntax='proto3',
  serialized_options=_b('\n*org.apache.bookkeeper.stream.proto.clusterP\001'),
  serialized_pb=_b('\n\rcluster.proto\x12\x18\x62ookkeeper.proto.cluster\x1a\x0c\x63ommon.proto\"*\n\x14ServerAssignmentData\x12\x12\n\ncontainers\x18\x01 \x03(\x03\"\xc6\x01\n\x15\x43lusterAssignmentData\x12M\n\x07servers\x18\x01 \x03(\x0b\x32<.bookkeeper.proto.cluster.ClusterAssignmentData.ServersEntry\x1a^\n\x0cServersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..bookkeeper.proto.cluster.ServerAssignmentData:\x02\x38\x01\"1\n\x0f\x43lusterMetadata\x12\x1e\n\x16num_storage_containers\x18\x01 \x01(\x03\x42.\n*org.apache.bookkeeper.stream.proto.clusterP\x01\x62\x06proto3')
  ,
  dependencies=[common__pb2.DESCRIPTOR,])




_SERVERASSIGNMENTDATA = _descriptor.Descriptor(
  name='ServerAssignmentData',
  full_name='bookkeeper.proto.cluster.ServerAssignmentData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='containers', full_name='bookkeeper.proto.cluster.ServerAssignmentData.containers', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=99,
)


_CLUSTERASSIGNMENTDATA_SERVERSENTRY = _descriptor.Descriptor(
  name='ServersEntry',
  full_name='bookkeeper.proto.cluster.ClusterAssignmentData.ServersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='bookkeeper.proto.cluster.ClusterAssignmentData.ServersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='bookkeeper.proto.cluster.ClusterAssignmentData.ServersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=300,
)

_CLUSTERASSIGNMENTDATA = _descriptor.Descriptor(
  name='ClusterAssignmentData',
  full_name='bookkeeper.proto.cluster.ClusterAssignmentData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='servers', full_name='bookkeeper.proto.cluster.ClusterAssignmentData.servers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTERASSIGNMENTDATA_SERVERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=300,
)


_CLUSTERMETADATA = _descriptor.Descriptor(
  name='ClusterMetadata',
  full_name='bookkeeper.proto.cluster.ClusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_storage_containers', full_name='bookkeeper.proto.cluster.ClusterMetadata.num_storage_containers', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=351,
)

_CLUSTERASSIGNMENTDATA_SERVERSENTRY.fields_by_name['value'].message_type = _SERVERASSIGNMENTDATA
_CLUSTERASSIGNMENTDATA_SERVERSENTRY.containing_type = _CLUSTERASSIGNMENTDATA
_CLUSTERASSIGNMENTDATA.fields_by_name['servers'].message_type = _CLUSTERASSIGNMENTDATA_SERVERSENTRY
DESCRIPTOR.message_types_by_name['ServerAssignmentData'] = _SERVERASSIGNMENTDATA
DESCRIPTOR.message_types_by_name['ClusterAssignmentData'] = _CLUSTERASSIGNMENTDATA
DESCRIPTOR.message_types_by_name['ClusterMetadata'] = _CLUSTERMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServerAssignmentData = _reflection.GeneratedProtocolMessageType('ServerAssignmentData', (_message.Message,), dict(
  DESCRIPTOR = _SERVERASSIGNMENTDATA,
  __module__ = 'cluster_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.cluster.ServerAssignmentData)
  ))
_sym_db.RegisterMessage(ServerAssignmentData)

ClusterAssignmentData = _reflection.GeneratedProtocolMessageType('ClusterAssignmentData', (_message.Message,), dict(

  ServersEntry = _reflection.GeneratedProtocolMessageType('ServersEntry', (_message.Message,), dict(
    DESCRIPTOR = _CLUSTERASSIGNMENTDATA_SERVERSENTRY,
    __module__ = 'cluster_pb2'
    # @@protoc_insertion_point(class_scope:bookkeeper.proto.cluster.ClusterAssignmentData.ServersEntry)
    ))
  ,
  DESCRIPTOR = _CLUSTERASSIGNMENTDATA,
  __module__ = 'cluster_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.cluster.ClusterAssignmentData)
  ))
_sym_db.RegisterMessage(ClusterAssignmentData)
_sym_db.RegisterMessage(ClusterAssignmentData.ServersEntry)

ClusterMetadata = _reflection.GeneratedProtocolMessageType('ClusterMetadata', (_message.Message,), dict(
  DESCRIPTOR = _CLUSTERMETADATA,
  __module__ = 'cluster_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.cluster.ClusterMetadata)
  ))
_sym_db.RegisterMessage(ClusterMetadata)


DESCRIPTOR._options = None
_CLUSTERASSIGNMENTDATA_SERVERSENTRY._options = None
# @@protoc_insertion_point(module_scope)
