# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kv_store.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import bookkeeper.proto.kv_pb2 as kv__pb2
import bookkeeper.proto.kv_rpc_pb2 as kv__rpc__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kv_store.proto',
  package='bookkeeper.proto.kv.store',
  syntax='proto3',
  serialized_options=_b('\n+org.apache.bookkeeper.stream.proto.kv.storeP\001'),
  serialized_pb=_b('\n\x0ekv_store.proto\x12\x19\x62ookkeeper.proto.kv.store\x1a\x08kv.proto\x1a\x0ckv_rpc.proto\"\x83\x01\n\x07KeyMeta\x12\x17\n\x0f\x63reate_revision\x18\x01 \x01(\x03\x12\x14\n\x0cmod_revision\x18\x02 \x01(\x03\x12\x0f\n\x07version\x18\x03 \x01(\x03\x12\x38\n\nvalue_type\x18\x04 \x01(\x0e\x32$.bookkeeper.proto.kv.store.ValueType\"\x0c\n\nNopRequest\"\xbc\x02\n\x07\x43ommand\x12\x38\n\x07nop_req\x18\x01 \x01(\x0b\x32%.bookkeeper.proto.kv.store.NopRequestH\x00\x12\x36\n\x07put_req\x18\x02 \x01(\x0b\x32#.bookkeeper.proto.kv.rpc.PutRequestH\x00\x12\x41\n\ndelete_req\x18\x03 \x01(\x0b\x32+.bookkeeper.proto.kv.rpc.DeleteRangeRequestH\x00\x12\x36\n\x07txn_req\x18\x04 \x01(\x0b\x32#.bookkeeper.proto.kv.rpc.TxnRequestH\x00\x12=\n\x08incr_req\x18\x05 \x01(\x0b\x32).bookkeeper.proto.kv.rpc.IncrementRequestH\x00\x42\x05\n\x03req\"E\n\x12\x43heckpointMetadata\x12\r\n\x05\x66iles\x18\x01 \x03(\t\x12\x0c\n\x04txid\x18\x02 \x01(\x0c\x12\x12\n\ncreated_at\x18\x03 \x01(\x04*\"\n\tValueType\x12\t\n\x05\x42YTES\x10\x00\x12\n\n\x06NUMBER\x10\x01\x42/\n+org.apache.bookkeeper.stream.proto.kv.storeP\x01\x62\x06proto3')
  ,
  dependencies=[kv__pb2.DESCRIPTOR,kv__rpc__pb2.DESCRIPTOR,])

_VALUETYPE = _descriptor.EnumDescriptor(
  name='ValueType',
  full_name='bookkeeper.proto.kv.store.ValueType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BYTES', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NUMBER', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=607,
  serialized_end=641,
)
_sym_db.RegisterEnumDescriptor(_VALUETYPE)

ValueType = enum_type_wrapper.EnumTypeWrapper(_VALUETYPE)
BYTES = 0
NUMBER = 1



_KEYMETA = _descriptor.Descriptor(
  name='KeyMeta',
  full_name='bookkeeper.proto.kv.store.KeyMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create_revision', full_name='bookkeeper.proto.kv.store.KeyMeta.create_revision', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mod_revision', full_name='bookkeeper.proto.kv.store.KeyMeta.mod_revision', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='bookkeeper.proto.kv.store.KeyMeta.version', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_type', full_name='bookkeeper.proto.kv.store.KeyMeta.value_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=201,
)


_NOPREQUEST = _descriptor.Descriptor(
  name='NopRequest',
  full_name='bookkeeper.proto.kv.store.NopRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=215,
)


_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='bookkeeper.proto.kv.store.Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nop_req', full_name='bookkeeper.proto.kv.store.Command.nop_req', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='put_req', full_name='bookkeeper.proto.kv.store.Command.put_req', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_req', full_name='bookkeeper.proto.kv.store.Command.delete_req', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txn_req', full_name='bookkeeper.proto.kv.store.Command.txn_req', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incr_req', full_name='bookkeeper.proto.kv.store.Command.incr_req', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='bookkeeper.proto.kv.store.Command.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=218,
  serialized_end=534,
)


_CHECKPOINTMETADATA = _descriptor.Descriptor(
  name='CheckpointMetadata',
  full_name='bookkeeper.proto.kv.store.CheckpointMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='bookkeeper.proto.kv.store.CheckpointMetadata.files', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txid', full_name='bookkeeper.proto.kv.store.CheckpointMetadata.txid', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='bookkeeper.proto.kv.store.CheckpointMetadata.created_at', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=605,
)

_KEYMETA.fields_by_name['value_type'].enum_type = _VALUETYPE
_COMMAND.fields_by_name['nop_req'].message_type = _NOPREQUEST
_COMMAND.fields_by_name['put_req'].message_type = kv__rpc__pb2._PUTREQUEST
_COMMAND.fields_by_name['delete_req'].message_type = kv__rpc__pb2._DELETERANGEREQUEST
_COMMAND.fields_by_name['txn_req'].message_type = kv__rpc__pb2._TXNREQUEST
_COMMAND.fields_by_name['incr_req'].message_type = kv__rpc__pb2._INCREMENTREQUEST
_COMMAND.oneofs_by_name['req'].fields.append(
  _COMMAND.fields_by_name['nop_req'])
_COMMAND.fields_by_name['nop_req'].containing_oneof = _COMMAND.oneofs_by_name['req']
_COMMAND.oneofs_by_name['req'].fields.append(
  _COMMAND.fields_by_name['put_req'])
_COMMAND.fields_by_name['put_req'].containing_oneof = _COMMAND.oneofs_by_name['req']
_COMMAND.oneofs_by_name['req'].fields.append(
  _COMMAND.fields_by_name['delete_req'])
_COMMAND.fields_by_name['delete_req'].containing_oneof = _COMMAND.oneofs_by_name['req']
_COMMAND.oneofs_by_name['req'].fields.append(
  _COMMAND.fields_by_name['txn_req'])
_COMMAND.fields_by_name['txn_req'].containing_oneof = _COMMAND.oneofs_by_name['req']
_COMMAND.oneofs_by_name['req'].fields.append(
  _COMMAND.fields_by_name['incr_req'])
_COMMAND.fields_by_name['incr_req'].containing_oneof = _COMMAND.oneofs_by_name['req']
DESCRIPTOR.message_types_by_name['KeyMeta'] = _KEYMETA
DESCRIPTOR.message_types_by_name['NopRequest'] = _NOPREQUEST
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
DESCRIPTOR.message_types_by_name['CheckpointMetadata'] = _CHECKPOINTMETADATA
DESCRIPTOR.enum_types_by_name['ValueType'] = _VALUETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeyMeta = _reflection.GeneratedProtocolMessageType('KeyMeta', (_message.Message,), dict(
  DESCRIPTOR = _KEYMETA,
  __module__ = 'kv_store_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.store.KeyMeta)
  ))
_sym_db.RegisterMessage(KeyMeta)

NopRequest = _reflection.GeneratedProtocolMessageType('NopRequest', (_message.Message,), dict(
  DESCRIPTOR = _NOPREQUEST,
  __module__ = 'kv_store_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.store.NopRequest)
  ))
_sym_db.RegisterMessage(NopRequest)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), dict(
  DESCRIPTOR = _COMMAND,
  __module__ = 'kv_store_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.store.Command)
  ))
_sym_db.RegisterMessage(Command)

CheckpointMetadata = _reflection.GeneratedProtocolMessageType('CheckpointMetadata', (_message.Message,), dict(
  DESCRIPTOR = _CHECKPOINTMETADATA,
  __module__ = 'kv_store_pb2'
  # @@protoc_insertion_point(class_scope:bookkeeper.proto.kv.store.CheckpointMetadata)
  ))
_sym_db.RegisterMessage(CheckpointMetadata)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
